'use strict';

var _actions = require('../actions');

beforeEach(function () {
  console.error = jest.fn();
}); /* eslint-disable no-console */


describe('showAlert', function () {
  it('should create SHOW action', function () {
    var payload = { title: 'show' };
    expect((0, _actions.showAlert)(payload)).toEqual({
      type: _actions.SHOW,
      payload: { title: 'show' }
    });
    expect(console.error).not.toBeCalled();
  });

  it('should allow custom option in payload', function () {
    var payload = {
      title: 'show',
      onCancel: function onCancel() {}
    };
    (0, _actions.showAlert)(payload);
    expect(console.error).not.toBeCalled();
  });

  it('should warn for invalid props', function () {
    var payload = { titl: 'show' };
    (0, _actions.showAlert)(payload);
    expect(console.error).toBeCalledWith('Warning: Property titl is invalid. You can not pass it to SweetAlert');
  });
});

describe('replaceAlert', function () {
  it('should create REPLACE action', function () {
    var payload = { title: 'replace' };
    expect((0, _actions.replaceAlert)(payload)).toEqual({
      type: _actions.REPLACE,
      payload: { title: 'replace' }
    });
  });

  it('should warn for invalid props', function () {
    var payload = { titl: 'replace' };
    (0, _actions.replaceAlert)(payload);
    expect(console.error).toBeCalledWith('Warning: Property titl is invalid. You can not pass it to SweetAlert');
  });
});

describe('dismissAlert', function () {
  it('should create DISMISS action', function () {
    expect((0, _actions.dismissAlert)()).toEqual({
      type: _actions.DISMISS
    });
  });
});