'use strict';

var _immutable = require('immutable');

var _actions = require('../actions');

/* eslint-disable global-require */
beforeEach(function () {
  jest.resetModules();
});

it('should handle SHOW action', function () {
  var immutableReducer = require('../reducer-immutable').default;
  var prevState = (0, _immutable.fromJS)({
    show: false,
    title: ''
  });
  var showAction = {
    type: _actions.SHOW,
    payload: {
      title: 'show'
    }
  };
  expect(immutableReducer(prevState, showAction).toJS()).toEqual({
    show: true,
    title: 'show'
  });
});

it('should handle REPLACE action', function () {
  var immutableReducer = require('../reducer-immutable').default;
  var prevState = (0, _immutable.fromJS)({
    show: true,
    title: 'show'
  });
  var replaceAction = {
    type: _actions.REPLACE,
    payload: {
      title: 'replace'
    }
  };
  expect(immutableReducer(prevState, replaceAction).toJS()).toEqual({
    show: true,
    title: 'replace'
  });
});

it('should handle DISMISS action', function () {
  var immutableReducer = require('../reducer-immutable').default;
  var prevState = (0, _immutable.fromJS)({
    show: true,
    title: 'replace'
  });
  var dismissAction = {
    type: _actions.DISMISS
  };
  expect(immutableReducer(prevState, dismissAction).toJS()).toEqual({
    show: false,
    title: ''
  });
});

it('should warning when immutable is not installed', function () {
  /* eslint-disable no-console */
  console.error = jest.fn();
  jest.mock('immutable', function () {
    throw new Error('Cannot find module \'immutable\'');
  });
  var immutableReducer = require('../reducer-immutable').default;
  immutableReducer();
  expect(console.error).toBeCalledWith('Warning: You must install immutable-js for the immutable reducer to work!');
  /* eslint-enable no-console */
});